@@ -93,7 +93,7 @@ class SummaryPlotter:
             ):
                 label_bestfit += f" {c_name}={c_value:.3f}$\pm${c_error:.3f}"
 
-        data_err = np.diagonal(self.config.cov)
+        data_err = np.sqrt(np.diagonal(self.config.cov))
 
         half_bin_width = [
             (self.config.bins[i + 1] - self.config.bins[i]) / 2
@@ -156,7 +156,7 @@ class SummaryPlotter:
             # range=ranges, todo: Reimplement
             quantiles=[0.16, 0.84],
             # levels=(1 - np.exp(-0.5),), Causes ValueError: Contour levels must be increasing
-            truths=np.zeros(len(labels)),
+            truths=np.zeros(len(self.config.tex_labels)),
             show_titles=True,
             title_kwargs={"fontsize": 18},
             **corner_kwargs,
